[Libreoffice-commits] core.git: include/rtl sal/rtl sal/util sc/inc

Tor Lillqvist tml at collabora.com
Thu Feb 27 22:28:58 PST 2014


 include/rtl/alloc.h      |    4 ++--
 sal/rtl/alloc_global.cxx |    2 +-
 sal/util/sal.map         |    2 +-
 sc/inc/stlalgorithm.hxx  |    2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

New commits:
commit 9aab0e9ac656be862049a592587865f7c15f0fd4
Author: Tor Lillqvist <tml at collabora.com>
Date:   Fri Feb 28 08:27:17 2014 +0200

    Fix typo: s/Alined/Aligned
    
    Change-Id: I248d002d2ed0e61f97a35ea0d329c64832252ad7

diff --git a/sal/rtl/alloc_global.cxx b/sal/rtl/alloc_global.cxx
index 4108333..0c02efd 100644
--- a/sal/rtl/alloc_global.cxx
+++ b/sal/rtl/alloc_global.cxx
@@ -379,7 +379,7 @@ void SAL_CALL rtl_freeZeroMemory (void * p, sal_Size n) SAL_THROW_EXTERN_C()
     }
 }
 
-void* SAL_CALL rtl_allocateAlinedMemory (sal_Size Alignment, sal_Size Bytes) SAL_THROW_EXTERN_C()
+void* SAL_CALL rtl_allocateAlignedMemory (sal_Size Alignment, sal_Size Bytes) SAL_THROW_EXTERN_C()
 {
     return osl_aligned_alloc(Alignment, Bytes);
 }
diff --git a/sal/util/sal.map b/sal/util/sal.map
index f63f38b..900d077 100644
--- a/sal/util/sal.map
+++ b/sal/util/sal.map
@@ -672,7 +672,7 @@ LIBO_UDK_4.2 { # symbols available in >= LibO 4.2
 
 LIBO_UDK_4.3 { # symbols available in >= LibO 4.3
     global:
-        rtl_allocateAlinedMemory;
+        rtl_allocateAlignedMemory;
         rtl_freeAlignedMemory;
 } LIBO_UDK_4.2;
 
diff --git a/sc/inc/stlalgorithm.hxx b/sc/inc/stlalgorithm.hxx
index 37d7ba8..bda11bf 100644
--- a/sc/inc/stlalgorithm.hxx
+++ b/sc/inc/stlalgorithm.hxx
@@ -74,7 +74,7 @@ public:
 
     pointer allocate(size_type n)
     {
-        return (pointer)rtl_allocateAlinedMemory(_Alignment, n*sizeof(value_type));
+        return (pointer)rtl_allocateAlignedMemory(_Alignment, n*sizeof(value_type));
     }
 
     void deallocate(pointer p, size_type)


More information about the Libreoffice-commits mailing list
diff --git a/include/rtl/alloc.h b/include/rtl/alloc.h
index f3459ba..01a556b 100644
--- a/include/rtl/alloc.h
+++ b/include/rtl/alloc.h
@@ -105,13 +105,13 @@ SAL_DLLPUBLIC void SAL_CALL rtl_freeZeroMemory (
     @param  Bytes [in] memory size.
     @return pointer to allocated memory.
  */
-SAL_DLLPUBLIC void* SAL_CALL rtl_allocateAlinedMemory (
+SAL_DLLPUBLIC void* SAL_CALL rtl_allocateAlignedMemory (
     sal_Size Alignment,
     sal_Size Bytes
 ) SAL_THROW_EXTERN_C();
 
 
 /** Free memory allocated with rtl_allocateAlinedMemory.
     @param  Ptr   [in] pointer to previously allocated memory.
     @return none. Memory is released. Ptr is invalid.
  */
@@ -105,13 +105,13 @@ SAL_DLLPUBLIC void SAL_CALL rtl_freeZeroMemory (
 
 
-/** Free memory allocated with rtl_allocateAlinedMemory.
+/** Free memory allocated with rtl_allocateAlignedMemory.
     @param  Ptr   [in] pointer to previously allocated memory.
     @return none. Memory is released. Ptr is invalid.